==> apiconnect-cli-util-1.0.3.tgz: package/lib/util/util.js <==
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-util
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
/*eslint brace-style: 0, max-len: 0*/

/**
 * Return the user's home directory
 *
 * @returns {String}
 */

var fs = require('fs');
var os = require('os');
var path = require('path');
var debug = require('debug')('apiconnect-cli-util:util');
var Chance = require('chance');
var Netrc = require('./netrc');
var logger = require('apiconnect-cli-logger');
var version = require('../../package.json').version;
var ServerError = require('./server-error');
var Context = require('./context').Context;

//var protocol = 'apic-mgmt';

var PREFIX = 'api-';

/**
 * Return the user's home directory
 * @type {userHome}
 */
module.exports.userHome = userHome;
function userHome() {
  return process.env.HOME || process.env.USERPROFILE;
}
//Return the path to the apic configs directory
module.exports.apicHomePath = apicHomePath;
function apicHomePath() {
  return userHome() + '/.apic';
}


module.exports.sslOptions = sslOptions;
/**
 * Return the p12 file that can be used to connect to self-signed endpoints
 *
 * @return {object} example {pfxPath: <filepath>, passphrase: <password>}
 */
function sslOptions() {
  var obj = {
    rejectedUnauthorized: false,
  };
  obj.pfxPath = __dirname + '/../ssl/certificate.p12';
  obj.passphrase = 'onpremise';
  return obj;
}

/**
 * Return the User Agent used that is send when a http request is being made.
 * @type {userAgent}
 */
module.exports.userAgent = userAgent;
function userAgent() {
  return 'APIC Toolkit/' + version + ' (' + os.type() + '; ' +
    os.platform() + '; ' + os.arch() + ')';
}

module.exports.requestOptions = requestOptions;
/**
 * Return the base request options that will be used to communicate with
 * an apic stack
 *
 * @param username
 * @param password
 * @param host
 * @returns
 * {{auth: {user: string, pass: *}, agentOptions:
  * {pfx: *, passphrase: *, rejectUnauthorized: boolean},
 *   url: string}}
 */
function requestOptions(username, password, host) {
  var sslOptions = module.exports.sslOptions();
  var pfxdata = fs.readFileSync(sslOptions.pfxPath);
  var base = {
    auth: {
      user: username,
      pass: password,
    },
    headers: {
      'user-agent': userAgent(),
      accept: 'application/json',
    },
    agentOptions: {
      pfx: pfxdata,
      passphrase: sslOptions.passphrase,
      rejectUnauthorized: false,
    },
    url: 'https://' + host,
  };
  return base;
}

module.exports.requestDefaultOptions = requestDefaultOptions;
/**
 * Return the default options to connect to the api management backend api
 * @returns
 * {
 *   {
 *          auth: {username: *, password: *},
 *       headers: {user-agent: string},
 *  agentOptions: {pfx: *, passphrase: (*|string), rejectUnauthorized: boolean},
  *          url: string
  *   }
  * }
 */
function requestDefaultOptions() {
  var machine = Context.get().server;
  var credential = Netrc.lookup(machine);
  var sslOptions = module.exports.sslOptions();
  var user = credential ? credential.login : Context.get().username;
  var pass = credential && credential.password ? credential.password : Context.get().password;
  var base = {
    auth: {
      username: user,
      password: pass,
    },
    headers: {
      'user-agent': userAgent(),
      accept: 'application/json',
    },
    agentOptions: {
      pfx: fs.readFileSync(sslOptions.pfxPath),
      passphrase: sslOptions.passphrase,
      rejectUnauthorized: false,
    },
    method: 'GET',
    url: 'https://' + machine,
  };
  return base;
}

module.exports.generateSlugFromText = generateSlugFromText;
function generateSlugFromText(text) {
  if (!text) {
    return generateRandomSlug(PREFIX);
  }

  // Remove the intial and ending spaces
  text = text.trim();

  //transform spaces to dash
  text = text.replace(/\s+/g, '-');

  //remove any characters that are not a-zA-Z_-0-9
  text = text.replace(/[^A-Za-z_\-0-9]/g, '');

  //make all text lowercase
  text = text.toLowerCase();

  if (text === '' || text === '-') {
    return generateRandomSlug(PREFIX);
  }

  return text;
}

function generateRandomSlug(prefix) {
  var randomWord = new Chance();
  var uniqueText = randomWord.word({ length: 5 });
  return prefix + uniqueText;
}

module.exports.providerOrgName = providerOrgName;
function providerOrgName() {
  return Context.get().organizations;
}

module.exports.host = host;
function host() {
  return Context.get().server;
}

module.exports.username = username;
function username() {
  if (Context.get().auth) {
    return Context.get().auth.split(':')[0];
  }
  return '';
}

module.exports.password = password;
function password() {
  if (Context.get().auth && Context.get().auth.indexOf(':') !== -1) {
    return Context.get().auth.split(':')[1];
  }
  return '';
}

module.exports.catalogName = catalogName;
function catalogName() {
  return Context.get().catalogs;
}

module.exports.stringifyServerError = stringifyServerError;
/**
 * Stringify an error response coming from server
 * @param body
 * @returns {string}
 */
function stringifyServerError(body) {
  var msg = 'Error: ';
  if (body && body.errors) {
    for (var i = 0; i < body.errors.length; i++) {
      var e = body.errors[i];
      for (var propName in e) {
        msg += e[propName] + '\n';
      }
    }
  }
  return msg;
}

module.exports.stringifyError = stringifyError;
function stringifyError(error) {
  if (error instanceof ServerError) {
    return error.toString();
  }
  var msg = 'Error: ';
  var body;
  if (error.body) {
    if (error.body || typeof error.body === 'string') {
      try {
        body = JSON.parse(error.body);
      }
      catch (err) {
        body = error.body;
      }
    }
    else {
      body = error.body;
    }
  }
  else {
    body = typeof error.message === 'object' ? JSON.parse(error.message) : error.message;
  }
  if (body && body.errors) {
    for (var i = 0; i < body.errors.length; i++) {
      var e = body.errors[i];
      for (var propName in e) {
        msg += e[propName];
      }
    }
  }
  else {
    msg += body;
  }
  return msg;
}

module.exports.checkForOrgOrAllOrgAndCatalogOrCatalog = checkForOrgOrAllOrgAndCatalogOrCatalog;
function checkForOrgOrAllOrgAndCatalogOrCatalog(opts) {
  if (!opts.organization && !opts.allOrganizations) {
    logger.writeln('--organization|--all-organizations is required or needs to be set via $apic config:set catalog');
    process.exit(1);
  }
  if (!opts.catalog && !opts.allCatalogs) {
    logger.writeln('--catalog|--all-catalogs is required or needs to be set via $apic config:set catalog');
    process.exit(1);
  }
};

module.exports.checkForOrgOrCatalog = checkForOrgOrCatalog;
function checkForOrgOrCatalog(opts) {
  checkForOrg(opts);
  checkForCatalog(opts);
};

module.exports.checkForOrg = checkForOrg;
function checkForOrg(opts) {
  if (!opts.organization) {
    logger.error('The --organization option is required or the catalog configuration ' +
      'variable must be set using the "apic config:set catalog=" command.');
    process.exit(1);
  }
};

module.exports.checkForCatalog = checkForCatalog;
function checkForCatalog(opts) {
  if (!opts.catalog) {
    logger.writeln('--catalog is required or needs to be set via $apic config:set catalog');
    process.exit(1);
  }
};

module.exports.getHelpFileContent = getHelpFileContent;
/**
 * Return the content of <tt>fileName</tt>
 * @param parentDir
 * @param fileName
 */
function getHelpFileContent(parentDir, fileName) {
  var absolutePath = path.resolve(parentDir, fileName);
  debug('Reading content for: ' + absolutePath);
  var data = fs.readFileSync(absolutePath);
  return data.toString();
}

==> apiconnect-cli-util-3.0.3.tgz: package/lib/util/util.js <==
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-util
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
/*eslint brace-style: 0, max-len: 0*/

/**
 * Return the user's home directory
 *
 * @returns {String}
 */

var Chance = require('chance');
var Context = require('./context').Context;
var ServerError = require('./server-error');
var Url = require('url');
var debug = require('debug')('apiconnect-cli-util:util');
var fs = require('fs');
var os = require('os');
var path = require('path');
var version = require('../../package.json').version;

//var protocol = 'apic-mgmt';

var PREFIX = 'api-';

/**
 * Return the user's home directory
 * @type {userHome}
 */
module.exports.userHome = userHome;
function userHome() {
  return process.env.HOME || process.env.USERPROFILE;
}
//Return the path to the apic configs directory
module.exports.apicHomePath = apicHomePath;
function apicHomePath() {
  return userHome() + '/.apic';
}


module.exports.sslOptions = sslOptions;
/**
 * Return the p12 file that can be used to connect to self-signed endpoints
 *
 * @return {object} example {pfxPath: <filepath>, passphrase: <password>}
 */
function sslOptions() {
  var obj = {
    rejectedUnauthorized: false,
  };
  obj.pfxPath = __dirname + '/../ssl/certificate.p12';
  obj.passphrase = 'onpremise';
  return obj;
}

/**
 * Return the User Agent used that is send when a http request is being made.
 * @type {userAgent}
 */
module.exports.userAgent = userAgent;
function userAgent() {
  return 'APIC Toolkit/' + version + ' (' + os.type() + '; ' +
    os.platform() + '; ' + os.arch() + ')';
}

module.exports.requestOptions = requestOptions;
/**
 * Return the base request options that will be used to communicate with
 * an apic stack
 *
 * @param username
 * @param password
 * @param host
 * @returns
 * {{auth: {user: string, pass: *}, agentOptions:
  * {pfx: *, passphrase: *, rejectUnauthorized: boolean},
 *   url: string}}
 */
function requestOptions(username, password, host) {
  var sslOptions = module.exports.sslOptions();
  var pfxdata = fs.readFileSync(sslOptions.pfxPath);
  var base = {
    headers: {
      'user-agent': userAgent(),
      accept: 'application/json',
    },
    agentOptions: {
      pfx: pfxdata,
      passphrase: sslOptions.passphrase,
      rejectUnauthorized: false,
    },
    url: 'https://' + host,
  };
  if (username && password) {
    base.auth = {
      user: username,
      pass: password,
    };
  }
  return base;
}

module.exports.requestDefaultOptions = requestDefaultOptions;
/**
 * Return the default options to connect to the api management backend api
 * @returns
 * {
 *   {
 *          auth: {username: *, password: *},
 *       headers: {user-agent: string},
 *  agentOptions: {pfx: *, passphrase: (*|string), rejectUnauthorized: boolean},
  *          url: string
  *   }
  * }
 */
function requestDefaultOptions(hostname) {
  var apicAuth = require('../auth/auth');

  hostname = hostname || Context.get().server;
  var machine = 'https://' + hostname;
  var creds = apicAuth.getCredentials({ uri: Url.parse(machine) });

  var sslOptions = module.exports.sslOptions();
  var base = {
    headers: {
      'user-agent': userAgent(),
      accept: 'application/json',
    },
    agentOptions: {
      pfx: fs.readFileSync(sslOptions.pfxPath),
      passphrase: sslOptions.passphrase,
      rejectUnauthorized: false,
    },
    method: 'GET',
    url: machine,
  };

  // NOTE: Creds should be populated and checked by plugin so if no creds are available try an unauthenticated request
  if (creds) {
    if (creds.username) {
      base.auth = {
        username: creds.username,
        password: creds.password,
      };
    } else if (creds.token) {
      base.auth = {
        bearer: creds.token,
      };
    }
  }

  return base;
}

module.exports.generateSlugFromText = generateSlugFromText;
function generateSlugFromText(text) {
  if (!text) {
    return generateRandomSlug(PREFIX);
  }

  // Remove the intial and ending spaces
  text = text.trim();

  //transform spaces to dash
  text = text.replace(/\s+/g, '-');

  //remove any characters that are not a-zA-Z_-0-9
  text = text.replace(/[^A-Za-z_\-0-9]/g, '');

  //make all text lowercase
  text = text.toLowerCase();

  if (text === '' || text === '-') {
    return generateRandomSlug(PREFIX);
  }

  return text;
}

function generateRandomSlug(prefix) {
  var randomWord = new Chance();
  var uniqueText = randomWord.word({ length: 5 });
  return prefix + uniqueText;
}

module.exports.providerOrgName = providerOrgName;
function providerOrgName() {
  return Context.get().organizations;
}

module.exports.host = host;
function host() {
  return Context.get().server;
}

module.exports.username = username;
function username() {
  if (Context.get().auth) {
    return Context.get().auth.split(':')[0];
  }
  return '';
}

module.exports.password = password;
function password() {
  if (Context.get().auth && Context.get().auth.indexOf(':') !== -1) {
    return Context.get().auth.split(':')[1];
  }
  return '';
}

module.exports.catalogName = catalogName;
function catalogName() {
  return Context.get().catalogs;
}

module.exports.stringifyServerError = stringifyServerError;
/**
 * Stringify an error response coming from server
 * @param body
 * @returns {string}
 */
function stringifyServerError(body) {
  var msg = 'Error: ';
  if (body && body.errors) {
    for (var i = 0; i < body.errors.length; i++) {
      var e = body.errors[i];
      for (var propName in e) {
        msg += e[propName] + '\n';
      }
    }
  }
  return msg;
}

module.exports.stringifyError = stringifyError;
function stringifyError(error) {
  if (error instanceof ServerError) {
    return error.toString();
  }
  var msg = 'Error: ';
  var body;
  if (error.body) {
    if (error.body || typeof error.body === 'string') {
      try {
        body = JSON.parse(error.body);
      }
      catch (err) {
        body = error.body;
      }
    }
    else {
      body = error.body;
    }
  }
  else {
    body = typeof error.message === 'object' ? JSON.parse(error.message) : error.message;
  }
  if (body && body.errors) {
    for (var i = 0; i < body.errors.length; i++) {
      var e = body.errors[i];
      for (var propName in e) {
        msg += e[propName];
      }
    }
  }
  else {
    msg += body;
  }
  return msg;
}

module.exports.checkForOrgOrAllOrgAndCatalogOrCatalog = checkForOrgOrAllOrgAndCatalogOrCatalog;
function checkForOrgOrAllOrgAndCatalogOrCatalog(opts) {
  if (opts.allOrganizations) {
    opts.organization = null;
  } else if (!opts.organization) {
    throw new Error('--organization or --all-organizations is required.');
  }

  if (opts.allCatalogs) {
    opts.catalog = null;
  } else if (!opts.catalog) {
    throw new Error('--catalog or --all-catalogs is required.');
  }
};

module.exports.checkForOrgOrCatalog = checkForOrgOrCatalog;
function checkForOrgOrCatalog(opts) {
  checkForOrg(opts);
  checkForCatalog(opts);
};

module.exports.checkForOrg = checkForOrg;
function checkForOrg(opts) {
  if (!opts.organization) {
    throw new Error('The --organization option is required or the catalog configuration ' +
      'variable must be set using the "apic config:set catalog=" command.');
  }
};

module.exports.checkForCatalog = checkForCatalog;
function checkForCatalog(opts) {
  if (!opts.catalog) {
    throw new Error('--catalog is required or needs to be set via $apic config:set catalog');
  }
};

module.exports.getHelpFileContent = getHelpFileContent;
/**
 * Return the content of <tt>fileName</tt>
 * @param parentDir
 * @param fileName
 */
function getHelpFileContent(parentDir, fileName) {
  var absolutePath = path.resolve(parentDir, fileName);
  debug('Reading content for: ' + absolutePath);
  var data = fs.readFileSync(absolutePath);
  return data.toString();
}
